@@ -1,6 +1,8 @@
 # coding=utf-8
 from .mc_campaign_defaults import MCCampaignDefaults
 from .mc_contact import MCContact
+from .mc_interest import MCInterest
+from .mc_interest_category import MCInterestCategory
 from .mc_link import MCLink
 from .mc_list import MCList
 from .mc_list_stats import MCListStats
